[Python-checkins] cpython: Improve exception text. Closes issue 13811.

eric.smith python-checkins at python.org
Fri Jan 20 02:04:44 CET 2012


http://hg.python.org/cpython/rev/5c33ebb50702
changeset:   74533:5c33ebb50702
user:        Eric V. Smith <eric at trueblade.com>
date:        Thu Jan 19 20:04:28 2012 -0500
summary:
  Improve exception text. Closes issue 13811.

files:
  Python/formatter_unicode.c |  4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/Python/formatter_unicode.c b/Python/formatter_unicode.c
--- a/Python/formatter_unicode.c
+++ b/Python/formatter_unicode.c
@@ -241,8 +241,8 @@
     /* Finally, parse the type field. */
 
     if (end-pos > 1) {
-        /* More than one char remain, invalid conversion spec. */
-        PyErr_Format(PyExc_ValueError, "Invalid conversion specification");
+        /* More than one char remain, invalid format specifier. */
+        PyErr_Format(PyExc_ValueError, "Invalid format specifier");
         return 0;
     }
 

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list